@@ -1,4 +1,4 @@
-package Algorithm::CheckDigits::M11_008;
+package Algorithm::CheckDigits::M11_002;
 
 use 5.006;
 use strict;
@@ -24,8 +24,6 @@ our @EXPORT_OK = ( 'new', @{ $EXPORT_TAGS{'all'} } );
 
 our @EXPORT = ();
 
-my @weight = ( 2, 7, 6, 5, 4, 3, 2, 1 );
-
 sub new {
 	my $proto = shift;
 	my $type  = shift;
@@ -37,43 +35,58 @@ sub new {
 
 sub is_valid {
 	my ($self,$number) = @_;
-	if ($number =~ /^(\d{8})$/) {
-		return 0 == $self->_compute_checkdigits($1);
+	if ($number =~ /^(.+)(.)$/) {
+		return uc($2) eq $self->_compute_checkdigit($1);
 	}
 	return ''
 } # is_valid()
 
 sub complete {
 	my ($self,$number) = @_;
-	return "$1" if(   $number =~ /^(\d{8})$/
-	              and 0 == $self->_compute_checkdigits($1));
+	if ($number =~ /^[0-9]+$/) {
+		my $cd = $self->_compute_checkdigit($number);
+		return $number . $cd unless 0 > $cd;
+	}
 	return '';
 } # complete()
 
 sub basenumber {
 	my ($self,$number) = @_;
-	return "$1" if(   $number =~ /^(\d{8})$/
-	              and 0 == $self->_compute_checkdigits($1));
+	if ($number =~ /^(.+)(.)$/) {
+		return $1 if (uc($2) eq $self->_compute_checkdigit($1));
+	}
 	return '';
 } # basenumber()
 
 sub checkdigit {
 	my ($self,$number) = @_;
-	return '' if(   $number =~ /^(\d{8})$/
-	            and 0 == $self->_compute_checkdigits($1));
-	return undef;
+	if ($number =~ /^(.+)(.)$/) {
+		return $2 if (uc($2) eq $self->_compute_checkdigit($1));
+	}
+	return '';
 } # checkdigit()
 
-sub _compute_checkdigits {
-	my $self    = shift;
+sub _compute_checkdigit {
+	my $self   = shift;
+	my $number = shift;
 
-	my @digits = split(//,shift);
-	my $sum = 0;
-	for (my $i = 0; $i <= $#digits; $i++) {
-		$sum += $weight[$i] * $digits[$i];
+	if ($number =~ /^[-0-9]+$/) {
+
+		$number =~ s/-//g;
+		my @digits = split(//,$number);
+		my $sum    = 0;
+		my $weight = 2;
+
+		for (my $i = 0; $i <= $#digits; $i++) {
+
+			$sum += $weight * $digits[$i];
+			++$weight;
+
+		}
+		$sum %= 11;
+		return 10 == $sum ? -1 : $sum;
 	}
-	$sum %= 11;
-	return $sum;
+	return -1;
 } # _compute_checkdigit()
 
 # Preloaded methods go here.
@@ -83,26 +96,26 @@ __END__
 
 =head1 NAME
 
-CheckDigits::M11_008 - compute check digits for VAT Registration Number (DK)
+CheckDigits::M11_002 - compute check digits for PZN (DE)
 
 =head1 SYNOPSIS
 
   use CheckDigits;
 
-  $ustid = CheckDigits('ustid_dk');
+  $pzn = CheckDigits('pzn');
 
-  if ($ustid->is_valid('13585628')) {
+  if ($pzn->is_valid('4877800')) {
 	# do something
   }
 
-  $cn = $ustid->complete('1358562');
-  # $cn = '13585628'
+  $cn = $pzn->complete('487780');
+  # $cn = '4877800'
 
-  $cd = $ustid->checkdigit('13585628');
-  # $cd = '8'
+  $cd = $pzn->checkdigit('4877800');
+  # $cd = '0'
 
-  $bn = $ustid->basenumber('13585628');
-  # $bn = '1358562';
+  $bn = $pzn->basenumber('4877800');
+  # $bn = '487780'
   
 =head1 DESCRIPTION
 
@@ -112,19 +125,22 @@ CheckDigits::M11_008 - compute check digits for VAT Registration Number (DK)
 
 =item 1
 
-Beginning left every digit is weighted with 2, 7, 6, 5, 4, 3, 2, 1
+From left to right beginning with the first position all digits are
+multiplied with 2,3,4,...
 
 =item 2
 
-The weighted digits are added.
+The sum of all products is computed.
 
 =item 3
 
-The sum from step 2 is taken modulo 11.
+The checkdigit ist the sum of step 2 taken modulo 11.
 
 =item 4
 
-The number is valid if the sum from step 3 is zero (0).
+If the checkdigit is '10' the whole number is not taken as a PZN.
+
+=over 8
 
 =back
 
@@ -134,19 +150,18 @@ The number is valid if the sum from step 3 is zero (0).
 
 =item is_valid($number)
 
-Returns true only if C<$number> consists solely of numbers and hyphens
-and the two digits in the middle
-are valid check digits according to the algorithm given above.
+Returns true only if C<$number> consists solely of numbers and the last digit
+is a valid check digit according to the algorithm given above.
 
 Returns false otherwise,
 
 =item complete($number)
 
-The check digit for C<$number> is computed and inserted into the
-middle of C<$number>.
+The check digit for C<$number> is computed and concatenated to the end
+of C<$number>.
 
 Returns the complete number with check digit or '' if C<$number>
-does not consist solely of digits, hyphens and spaces.
+does not consist solely of digits and spaces.
 
 =item basenumber($number)
 
@@ -157,9 +172,10 @@ Return '' otherwise.
 
 =item checkdigit($number)
 
-Returns '' if C<$number> is valid.
+Returns the checkdigit of C<$number> if C<$number> has a valid check
+digit.
 
-Return undef otherwise.
+Return '' otherwise.
 
 =back
 
@@ -175,6 +191,6 @@ Mathias Weidner, E<lt>mathias@weidner.in-bad-schmiedeberg.deE<gt>
 
 L<perl>,
 L<CheckDigits>,
-F<www.pruefziffernberechnung.de>,
+F<www.pruefziffernberechnung.de>.
 
 =cut
